==> adaendra_python_config_loader-0.1.3-py3-none-any.whl: adaendra_python_config_loader/AdaendraConfigs.py <==
from adaendra_immutable_dict.AdaendraImmutableDict import AdaendraImmutableDict

from src.adaendra_python_config_loader.AdaendraConfigsLoader import load_configs


class AdaendraConfigs(object):
    """
    The config loader.
    """

    # --- PARAMETERS
    configs = None

    # --- METHODS
    def __new__(cls, config_dict: dict):
        if not AdaendraConfigs.configs:
            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(config_dict)
        return AdaendraConfigs.configs

    def __getattr__(self, name):
        if not AdaendraConfigs.configs:
            raise AttributeError(
                f"No configs were loaded on start."
            )
        return getattr(self.configs, name)

    def __getattribute__(self, name):
        if not AdaendraConfigs.configs:
            load_configs()
            raise AttributeError(
                f"No configs were loaded on start."
            )
        return getattr(self.configs, name)

    def __setattr__(self, name):
        """
        Unsupported method, will raise a TypeError.
        :raise: TypeError
        """
        raise TypeError(
            f"The configs can't be changed."
        )

    # --- INTERNAL CLASSES
    class __AdaendraConfigs:
        """
        The internal class to generate the singleton.
        """

        # --- METHODS
        def __init__(self, configs_dict: dict):
            self.configs_dict = AdaendraImmutableDict(configs_dict)

        def __str__(self):
            return "Configs : " + self.configs_dict.__repr__()

        def __getattr__(self, name):
            return self.configs_dict[name]


__all__ = (AdaendraConfigs.__name__,)

==> adaendra_python_config_loader-0.1.7-py3-none-any.whl: adaendra_python_config_loader/AdaendraConfigs.py <==
from adaendra_immutable_dict.AdaendraImmutableDict import AdaendraImmutableDict

from adaendra_python_config_loader.AdaendraConfigsLoader import load_configs


class AdaendraConfigs(object):
    """
    The config loader.
    """

    # --- PARAMETERS
    configs = None

    # --- METHODS
    def __init__(self):
        AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())

    def __new__(cls, config_dict: dict):
        if not AdaendraConfigs.configs:
            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(config_dict)
        return AdaendraConfigs.configs

    def __getattr__(self, name):
        if not AdaendraConfigs.configs:
            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
            raise AttributeError(
                f"No configs were loaded on start."
            )
        return getattr(self.configs, name)

    def __getattribute__(self, name):
        if not AdaendraConfigs.configs:
            AdaendraConfigs.configs = AdaendraConfigs.__AdaendraConfigs(load_configs())
            raise AttributeError(
                f"No configs were loaded on start."
            )
        return getattr(self.configs, name)

    def __setattr__(self, name):
        """
        Unsupported method, will raise a TypeError.
        :raise: TypeError
        """
        raise TypeError(
            f"The configs can't be changed."
        )

    # --- INTERNAL CLASSES
    class __AdaendraConfigs:
        """
        The internal class to generate the singleton.
        """

        # --- METHODS
        def __init__(self, configs_dict: dict):
            self.configs_dict = AdaendraImmutableDict(configs_dict)

        def __str__(self):
            return "Configs : " + self.configs_dict.__repr__()

        def __getattr__(self, name):
            return self.configs_dict[name]


__all__ = (AdaendraConfigs.__name__,)
